@@ -15,13 +15,13 @@ Usage::
 import sys
 from typing import Any, Dict, Type
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import ChangeTypeType, FormatTypeType, locationTypeType
 from .type_defs import (
-    CreateChangesetResponseResponseTypeDef,
-    GetProgrammaticAccessCredentialsResponseResponseTypeDef,
-    GetWorkingLocationResponseResponseTypeDef,
+    CreateChangesetResponseTypeDef,
+    GetProgrammaticAccessCredentialsResponseTypeDef,
+    GetWorkingLocationResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -50,20 +50,25 @@ class Exceptions:
     ValidationException: Type[BotocoreClientError]
 
 
-class FinSpaceDataClient:
+class FinSpaceDataClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/finspace-data.html#FinSpaceData.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/finspace-data.html#FinSpaceData.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        FinSpaceDataClient exceptions.
+        """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/finspace-data.html#FinSpaceData.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#can_paginate)
         """
 
@@ -77,11 +82,11 @@ class FinSpaceDataClient:
         formatType: FormatTypeType = None,
         formatParams: Dict[str, str] = None,
         tags: Dict[str, str] = None
-    ) -> CreateChangesetResponseResponseTypeDef:
+    ) -> CreateChangesetResponseTypeDef:
         """
         Creates a new changeset in a FinSpace dataset.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/finspace-data.html#FinSpaceData.Client.create_changeset)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#create_changeset)
         """
 
@@ -95,27 +100,27 @@ class FinSpaceDataClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/finspace-data.html#FinSpaceData.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#generate_presigned_url)
         """
 
     def get_programmatic_access_credentials(
         self, *, environmentId: str, durationInMinutes: int = None
-    ) -> GetProgrammaticAccessCredentialsResponseResponseTypeDef:
+    ) -> GetProgrammaticAccessCredentialsResponseTypeDef:
         """
         Request programmatic credentials to use with Habanero SDK.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/finspace-data.html#FinSpaceData.Client.get_programmatic_access_credentials)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_programmatic_access_credentials)
         """
 
     def get_working_location(
         self, *, locationType: locationTypeType = None
-    ) -> GetWorkingLocationResponseResponseTypeDef:
+    ) -> GetWorkingLocationResponseTypeDef:
         """
         A temporary Amazon S3 location to copy your files from a source location to
         stage or use as a scratch space in Habanero notebook.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/finspace-data.html#FinSpaceData.Client.get_working_location)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_finspace_data/client.html#get_working_location)
         """
